methodChannel property
The method channel used to interact with the native platform.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel('github_release_apk_updater');
The method channel used to interact with the native platform.
@visibleForTesting
final methodChannel = const MethodChannel('github_release_apk_updater');